svn commit: lorikeet r673 - in trunk/mod_ntlm_winbind: .

lmuelle at samba.org lmuelle at samba.org
Tue Nov 14 15:50:40 GMT 2006


Author: lmuelle
Date: 2006-11-14 15:50:40 +0000 (Tue, 14 Nov 2006)
New Revision: 673

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=lorikeet&rev=673

Log:
Rename mod_ntlm_winbind to mod_auth_ntlm_winbind even in the source code
and the README.

AP_MODULE_DECLARE_DATA or MODULE_VAR_EXPORT are now defined as
mod_auth_ntlm_winbind.

Modified:
   trunk/mod_ntlm_winbind/Makefile.in
   trunk/mod_ntlm_winbind/README
   trunk/mod_ntlm_winbind/mod_ntlm_winbind.c


Changeset:
Modified: trunk/mod_ntlm_winbind/Makefile.in
===================================================================
--- trunk/mod_ntlm_winbind/Makefile.in	2006-11-14 04:40:45 UTC (rev 672)
+++ trunk/mod_ntlm_winbind/Makefile.in	2006-11-14 15:50:40 UTC (rev 673)
@@ -1,5 +1,5 @@
 #
-# Makefile for mod_ntlm_winbind
+# Makefile for mod_auth_ntlm_winbind
 #
 
 # Programs

Modified: trunk/mod_ntlm_winbind/README
===================================================================
--- trunk/mod_ntlm_winbind/README	2006-11-14 04:40:45 UTC (rev 672)
+++ trunk/mod_ntlm_winbind/README	2006-11-14 15:50:40 UTC (rev 673)
@@ -1,5 +1,5 @@
-mod_ntlm_winbind is an Apache 1.x/2.x module that provides NTLM and
-Basic authentication via winbind.
+mod_auth_ntlm_winbind is an Apache 1.x/2.x module that provides NTLM
+and Basic authentication via winbind.
 
 INSTALLATION:
 The configure.in script and Makefile are essentially wrappers around
@@ -28,10 +28,10 @@
 (substitute apxs2 as appropriate)
 
 CONFIGURATION
-mod_ntlm_winbind uses the same ntlm_auth helper as the Squid proxy, so
-the same setup applies as for Squid: the winbindd_privileged directory
-must be accessible by the webserver userid. The configuration
-directives added by this module are as follows:
+mod_auth_ntlm_winbind uses the same ntlm_auth helper as the Squid
+proxy, so the same setup applies as for Squid: the winbindd_privileged
+directory must be accessible by the webserver userid. The
+configuration directives added by this module are as follows:
 
 NTLMAuth
   set to 'on' to activate NTLM authentication

Modified: trunk/mod_ntlm_winbind/mod_ntlm_winbind.c
===================================================================
--- trunk/mod_ntlm_winbind/mod_ntlm_winbind.c	2006-11-14 04:40:45 UTC (rev 672)
+++ trunk/mod_ntlm_winbind/mod_ntlm_winbind.c	2006-11-14 15:50:40 UTC (rev 673)
@@ -40,9 +40,9 @@
 /*
  * OVERVIEW:
  *
  * The mod_ntlm_winbind module allows authentication and authorisation over
  * the web against a Windows NT/2000/XP domain controller using the winbind
  * daemon running on the same machine apache is running on.
  *
  * Used only by IE and newer versions of Mozilla, the NTLM over HTTP protocol is completed undocumented
  * by Microsoft but  has been reverse engineered and described at the
@@ -130,7 +130,7 @@
 #define NEGOTIATE_AUTH_NAME "Negotiate"
 
 /* A structure to hold information about the configuration for the
-   mod_ntlm_winbind apache module. */
+   mod_auth_ntlm_winbind apache module. */
 
 typedef struct _ntlm_config_struct {
     unsigned int ntlm_on;
@@ -180,9 +180,9 @@
 } ntlm_context_t;
 
 #ifdef APACHE2
-module AP_MODULE_DECLARE_DATA ntlm_winbind_module;
+module AP_MODULE_DECLARE_DATA ntlm_auth_winbind_module;
 #else
-module MODULE_VAR_EXPORT ntlm_winbind_module;
+module MODULE_VAR_EXPORT ntlm_auth_winbind_module;
 #endif
 
 #define NTLM_DEBUG (APLOG_DEBUG | APLOG_NOERRNO)
@@ -340,7 +340,7 @@
 
 #ifdef APACHE2
     retval = (ntlm_connection_context_t *)ap_get_module_config( connection->conn_config,
-                                                                &ntlm_winbind_module );
+                                                                &ntlm_auth_winbind_module );
 #else
     retval = &global_connection_context;
 #endif
@@ -355,7 +355,7 @@
 {
     ntlm_config_rec *crec
         = (ntlm_config_rec *) ap_get_module_config(r->per_dir_config,
-                                                   &ntlm_winbind_module);
+                                                   &ntlm_auth_winbind_module);
     char *line;
     ntlm_connection_context_t *ctxt = get_connection_context( r->connection );
 
@@ -987,7 +987,7 @@
 static int check_user_id(request_rec * r) {
     ntlm_config_rec *crec =
         (ntlm_config_rec *) ap_get_module_config(r->per_dir_config,
-                                                 &ntlm_winbind_module);
+                                                 &ntlm_auth_winbind_module);
     ntlm_connection_context_t *ctxt = get_connection_context( r->connection );
     const char *auth_line = apr_table_get(r->headers_in,
                                           r->proxyreq ? "Proxy-Authorization"
@@ -1078,7 +1078,7 @@
 static int ntlm_pre_conn(conn_rec *c, void *csd) {
     ntlm_connection_context_t *ctxt = apr_pcalloc(c->pool, sizeof(ntlm_connection_context_t));
 
-    ap_set_module_config(c->conn_config, &ntlm_winbind_module, ctxt);
+    ap_set_module_config(c->conn_config, &ntlm_auth_winbind_module, ctxt);
 
     return OK;
 }
@@ -1090,7 +1090,7 @@
     ap_hook_check_user_id(check_user_id,NULL,NULL,APR_HOOK_MIDDLE);
 };
 
-module AP_MODULE_DECLARE_DATA ntlm_winbind_module = {
+module AP_MODULE_DECLARE_DATA ntlm_auth_winbind_module = {
     STANDARD20_MODULE_STUFF,
     ntlm_winbind_dir_config, /* create per-dir    config structures */
     NULL,                    /* merge  per-dir    config structures */
@@ -1100,7 +1100,7 @@
     register_hooks,          /* register hooks */
 };
 #else
-module MODULE_VAR_EXPORT ntlm_winbind_module = {
+module MODULE_VAR_EXPORT ntlm_auth_winbind_module = {
     STANDARD_MODULE_STUFF,
     NULL,                    /* module initializer                  */
     ntlm_winbind_dir_config, /* create per-dir    config structures */
@@ -40,9 +40,9 @@
  * OVERVIEW:
  *
- * The mod_ntlm_winbind module allows authentication and authorisation over
- * the web against a Windows NT/2000/XP domain controller using the winbind
- * daemon running on the same machine apache is running on.
+ * The mod_auth_ntlm_winbind module allows authentication and authorisation
+ * over the web against a Windows NT/2000/XP domain controller using the
+ * winbind daemon running on the same machine apache is running on.
  *
  * Used only by IE and newer versions of Mozilla, the NTLM over HTTP protocol is completed undocumented



More information about the samba-cvs mailing list